==> docusign-esign-java-4.4.0-sources.jar: com/docusign/esign/model/UserAuthorizationsResponse.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Objects;

/** UserAuthorizationsResponse. */
public class UserAuthorizationsResponse {
  @JsonProperty("results")
  private java.util.List<UserAuthorizationWithStatus> results = null;

  /**
   * results.
   *
   * @return UserAuthorizationsResponse
   */
  public UserAuthorizationsResponse results(java.util.List<UserAuthorizationWithStatus> results) {
    this.results = results;
    return this;
  }

  /**
   * addResultsItem.
   *
   * @return UserAuthorizationsResponse
   */
  public UserAuthorizationsResponse addResultsItem(UserAuthorizationWithStatus resultsItem) {
    if (this.results == null) {
      this.results = new java.util.ArrayList<>();
    }
    this.results.add(resultsItem);
    return this;
  }

  /**
   * .
   *
   * @return results
   */
  @Schema(description = "")
  public java.util.List<UserAuthorizationWithStatus> getResults() {
    return results;
  }

  /** setResults. */
  public void setResults(java.util.List<UserAuthorizationWithStatus> results) {
    this.results = results;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    UserAuthorizationsResponse userAuthorizationsResponse = (UserAuthorizationsResponse) o;
    return Objects.equals(this.results, userAuthorizationsResponse.results);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(results);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class UserAuthorizationsResponse {\n");

    sb.append("    results: ").append(toIndentedString(results)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-esign-java-6.4.0-sources.jar: com/docusign/esign/model/UserAuthorizationsResponse.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;

/** UserAuthorizationsResponse. */
public class UserAuthorizationsResponse implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("results")
  private java.util.List<UserAuthorizationWithStatus> results = null;

  /**
   * results.
   *
   * @return UserAuthorizationsResponse
   */
  public UserAuthorizationsResponse results(java.util.List<UserAuthorizationWithStatus> results) {
    this.results = results;
    return this;
  }

  /**
   * addResultsItem.
   *
   * @return UserAuthorizationsResponse
   */
  public UserAuthorizationsResponse addResultsItem(UserAuthorizationWithStatus resultsItem) {
    if (this.results == null) {
      this.results = new java.util.ArrayList<>();
    }
    this.results.add(resultsItem);
    return this;
  }

  /**
   * .
   *
   * @return results
   */
  @Schema(description = "")
  public java.util.List<UserAuthorizationWithStatus> getResults() {
    return results;
  }

  /** setResults. */
  public void setResults(java.util.List<UserAuthorizationWithStatus> results) {
    this.results = results;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    UserAuthorizationsResponse userAuthorizationsResponse = (UserAuthorizationsResponse) o;
    return Objects.equals(this.results, userAuthorizationsResponse.results);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(results);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class UserAuthorizationsResponse {\n");

    sb.append("    results: ").append(toIndentedString(results)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
